==> dposlib-0.3.4.tar.gz: dposlib-0.3.4/dposlib/net.py <==
# -*- coding: utf-8 -*-
# © Toons

ark = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "https://explorer.ark.io:8443"
    ]
}

dark = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 1,
    "txversion": 2,

    "seeds": [
        "https://dexplorer.ark.io:8443"
    ]
}

dark3 = {
    "familly": "ark.v3",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 1,
    "txversion": 2,

    "seeds": [
        "https://dexplorer.ark.io:8443"
    ]
}

iop = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,

    "seeds": [
        "http://35.195.150.223:4703",
        "http://34.76.165.50:4703",
        "http://104.155.17.122:4703",
        "http://35.228.202.124:4703",
        "http://35.228.73.165:4703",
        "http://35.198.174.42:4703",
        "http://35.246.135.62:4703",
        "http://34.90.0.113:4703",
        "http://34.90.43.152:4703",
        "http://34.66.138.96:4703",
        "http://104.154.142.55:4703",
        "http://34.74.102.192:4703",
        "http://35.231.24.181:4703",
        "http://35.233.159.123:4703",
        "http://35.230.119.77:4703",
        "http://35.235.109.207:4703",
        "http://34.94.151.12:4703",
        "http://35.203.123.223:4703",
        "http://35.240.251.207:4703",
        "http://35.190.233.247:4703",
        "http://34.93.248.166:4703"
    ]
}

diop = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,

    "seeds": [
        "http://35.204.124.143:4703",
        "http://34.68.118.161:4703",
        "http://35.228.196.114:4703",
        "http://34.87.3.205:4703",
        "http://35.185.32.241:4703",
        "http://35.240.62.119:4703"
    ]
}

qredit = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,

    "seeds": [
        "http://35.163.173.247:4103",
        "http://116.203.33.4:4103",
        "http://116.203.56.119:4103",
        "http://116.203.58.165:4103",
        "http://159.69.89.111:4103",
        "http://159.69.89.41:4103"
    ]
}

ripa = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,

    "seeds": [
        "http://51.15.84.120:5502"
    ]
}

==> dposlib-0.3.5.tar.gz: dposlib-0.3.5/dposlib/net.py <==
# -*- coding: utf-8 -*-

ark = {
    "familly": "ark.v3",
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "https://api.ark.io"
    ]
}

dark = {
    "familly": "ark.v3",
    "aip20": 1,
    "txversion": 2,

    "seeds": [
        "https://dwallets.ark.io"
    ]
}

iop = {
    "familly": "ark.v2",
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "http://35.195.150.223:4703",
        "http://34.76.165.50:4703",
        "http://104.155.17.122:4703",
        "http://35.228.202.124:4703",
        "http://35.228.73.165:4703",
        "http://35.198.174.42:4703",
        "http://35.246.135.62:4703",
        "http://34.90.0.113:4703",
        "http://34.90.43.152:4703",
        "http://34.66.138.96:4703",
        "http://104.154.142.55:4703",
        "http://34.74.102.192:4703",
        "http://35.231.24.181:4703",
        "http://35.233.159.123:4703",
        "http://35.230.119.77:4703",
        "http://35.235.109.207:4703",
        "http://34.94.151.12:4703",
        "http://35.203.123.223:4703",
        "http://35.240.251.207:4703",
        "http://35.190.233.247:4703",
        "http://34.93.248.166:4703"
    ]
}

diop = {
    "familly": "ark.v2",
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "http://35.204.124.143:4703",
        "http://34.68.118.161:4703",
        "http://35.228.196.114:4703",
        "http://34.87.3.205:4703",
        "http://35.185.32.241:4703",
        "http://35.240.62.119:4703"
    ]
}

qredit = {
    "familly": "ark.v2",
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "http://35.163.173.247:4103",
        "http://116.203.33.4:4103",
        "http://116.203.56.119:4103",
        "http://116.203.58.165:4103",
        "http://159.69.89.111:4103",
        "http://159.69.89.41:4103"
    ]
}

nos = {
    "familly": "ark.v2",
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "https://api.nos.dev"
    ]
}

uns = {
    "familly": "ark.v2",
    "maxvotepertx": 1,
    "maxvote": 1,
    "aip20": 0,
    "txversion": 2,

    "seeds": [
        "https://api.uns.network"
    ]
}
